@@ -6,6 +6,7 @@
   Copyright 2008-2009 Philipp Hagemeister
   Copyright 2015-2017 Joao Eriberto Mota Filho
   Copyright 2016      Stephen Thirlwall
+  Copyright 2017      Antonio Quartulli
   Copyright 2017      Ismael Luceno
 
   This program is free software; you can redistribute it and/or
@@ -39,6 +40,9 @@
 
 /* Main include file */
 
+#ifndef AXEL_AXEL_H
+#define AXEL_AXEL_H
+
 #include "config.h"
 
 #include <time.h>
@@ -46,7 +50,6 @@
 #include <fcntl.h>
 #include <errno.h>
 #include <stdio.h>
-#include <netdb.h>
 #ifndef	NOGETOPTLONG
 #define _GNU_SOURCE
 #include <getopt.h>
@@ -57,34 +60,33 @@
 #include <signal.h>
 #include <string.h>
 #include <stdarg.h>
+#include <stdbool.h>
 #include <sys/stat.h>
 #include <sys/time.h>
-#include <sys/types.h>
-#include <sys/ioctl.h>
-#include <sys/socket.h>
 #include <netinet/in_systm.h>
 #include <netinet/in.h>
 #include <netinet/ip.h>
 #include <arpa/inet.h>
 #include <net/if.h>
 #include <pthread.h>
-#include <openssl/ssl.h>
 
 /* Internationalization */
-#define PACKAGE			"axel"
-#define _( x )			gettext( x )
+#ifdef ENABLE_NLS
+#define _(x)			gettext(x)
 #include <libintl.h>
 #include <locale.h>
+#else
+#define _(x)			(x)
+#endif
 
 /* Compiled-in settings */
 #define MAX_STRING		1024
 #define MAX_ADD_HEADERS	10
-#define MAX_REDIR		5
-#define AXEL_VERSION_STRING	"2.13.1"
-#define DEFAULT_USER_AGENT	"Axel " AXEL_VERSION_STRING " (" ARCH ")"
+#define MAX_REDIRECT		20
+#define DEFAULT_IO_TIMEOUT	120
+#define DEFAULT_USER_AGENT	"Axel/" VERSION " (" ARCH ")"
 
-typedef struct
-{
+typedef struct {
 	void *next;
 	char text[MAX_STRING];
 } message_t;
@@ -100,30 +102,31 @@ typedef message_t if_t;
 #include "ssl.h"
 #include "search.h"
 
-#define min( a, b )		( (a) < (b) ? (a) : (b) )
-#define max( a, b )		( (a) > (b) ? (a) : (b) )
+#define min(a, b)		((a) < (b) ? (a) : (b))
+#define max(a, b)		((a) > (b) ? (a) : (b))
 
-typedef struct
-{
+typedef struct {
 	conn_t *conn;
-	conf_t conf[1];
+	conf_t *conf;
 	char filename[MAX_STRING];
 	double start_time;
 	int next_state, finish_time;
 	long long bytes_done, start_byte, size;
 	int bytes_per_second;
-	int delay_time;
+	struct timespec delay_time;
 	int outfd;
 	int ready;
 	message_t *message, *last_message;
 	url_t *url;
 } axel_t;
 
-axel_t *axel_new( conf_t *conf, int count, const void *url );
-int axel_open( axel_t *axel );
-void axel_start( axel_t *axel );
-void axel_do( axel_t *axel );
-void axel_close( axel_t *axel );
-void print_messages( axel_t *axel );
+axel_t *axel_new(conf_t *conf, int count, const void *url);
+int axel_open(axel_t *axel);
+void axel_start(axel_t *axel);
+void axel_do(axel_t *axel);
+void axel_close(axel_t *axel);
+void print_messages(axel_t *axel);
 
 double gettime();
+
+#endif				/* AXEL_AXEL_H */
