@@ -6,6 +6,8 @@
   Copyright 2016      Phillip Berndt
   Copyright 2016      Sjjad Hashemian
   Copyright 2016      Stephen Thirlwall
+  Copyright 2017      Antonio Quartulli
+  Copyright 2017      Ismael Luceno
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
@@ -38,16 +40,20 @@
 
 /* HTTP control include file */
 
-#define MAX_QUERY	2048		/* Should not grow larger.. */
+#ifndef AXEL_HTTP_H
+#define AXEL_HTTP_H
 
-typedef struct
-{
+#define MAX_QUERY	2048	/* Should not grow larger.. */
+
+typedef struct {
 	char host[MAX_STRING];
 	char auth[MAX_STRING];
 	char request[MAX_QUERY];
 	char headers[MAX_QUERY];
-	int proto;			/* FTP through HTTP proxies */
+	int port;
+	int proto;		/* FTP through HTTP proxies */
 	int proxy;
+	char proxy_auth[MAX_STRING];
 	long long int firstbyte;
 	long long int lastbyte;
 	int status;
@@ -55,14 +61,17 @@ typedef struct
 	char *local_if;
 } http_t;
 
-int http_connect( http_t *conn, int proto, char *proxy, char *host, int port, char *user, char *pass );
-void http_disconnect( http_t *conn );
-void http_get( http_t *conn, char *lurl );
-void http_addheader( http_t *conn, char *format, ... );
-int http_exec( http_t *conn );
-char *http_header( http_t *conn, char *header );
-void http_filename( http_t *conn, char *filename );
-long long int http_size( http_t *conn );
-long long int http_size_from_range( http_t *conn );
-void http_encode( char *s );
-void http_decode( char *s );
+int http_connect(http_t *conn, int proto, char *proxy, char *host, int port,
+		 char *user, char *pass, unsigned io_timeout);
+void http_disconnect(http_t *conn);
+void http_get(http_t *conn, char *lurl);
+void http_addheader(http_t *conn, char *format, ...);
+int http_exec(http_t *conn);
+const char *http_header(const http_t *conn, const char *header);
+void http_filename(const http_t *conn, char *filename);
+long long int http_size(http_t *conn);
+long long int http_size_from_range(http_t *conn);
+void http_encode(char *s);
+void http_decode(char *s);
+
+#endif				/* AXEL_HTTP_H */
