@@ -3,6 +3,8 @@
 
   Copyright 2016      Sjjad Hashemian
   Copyright 2016-2017 Stephen Thirlwall
+  Copyright 2017      Antonio Quartulli
+  Copyright 2017      Ismael Luceno
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
@@ -37,57 +39,69 @@
 
 #include "axel.h"
 
-#ifdef HAVE_OPENSSL
+#ifdef HAVE_SSL
 
 #include <openssl/err.h>
 
-static SSL_CTX *ssl_ctx = NULL;
+static pthread_mutex_t ssl_lock;
+static bool ssl_inited = false;
 static conf_t *conf = NULL;
 
-void ssl_init( conf_t *global_conf )
+void
+ssl_init(conf_t *global_conf)
 {
+	pthread_mutex_init(&ssl_lock, NULL);
 	conf = global_conf;
 }
 
-void ssl_startup( void )
+void
+ssl_startup(void)
 {
-	if( ssl_ctx != NULL )
-		return;
+	pthread_mutex_lock(&ssl_lock);
+	if (!ssl_inited) {
+		SSL_library_init();
+		SSL_load_error_strings();
 
-	SSL_library_init();
-	SSL_load_error_strings();
+		ssl_inited = true;
+	}
+	pthread_mutex_unlock(&ssl_lock);
+}
 
-	ssl_ctx = SSL_CTX_new( SSLv23_client_method() );
-	if( !conf->insecure ) {
+SSL *
+ssl_connect(int fd, char *hostname, char *message)
+{
+
+	SSL_CTX *ssl_ctx;
+	SSL *ssl;
+
+	ssl_startup();
+
+	ssl_ctx = SSL_CTX_new(SSLv23_client_method());
+	if (!conf->insecure) {
 		SSL_CTX_set_default_verify_paths(ssl_ctx);
 		SSL_CTX_set_verify(ssl_ctx, SSL_VERIFY_PEER, NULL);
 	}
 	SSL_CTX_set_mode(ssl_ctx, SSL_MODE_AUTO_RETRY);
-}
 
-SSL* ssl_connect( int fd, char *hostname, char *message )
-{
-	SSL* ssl;
-
-	ssl_startup();
-
-	ssl = SSL_new( ssl_ctx );
-	SSL_set_fd( ssl, fd );
+	ssl = SSL_new(ssl_ctx);
+	SSL_set_fd(ssl, fd);
 	SSL_set_tlsext_host_name(ssl, hostname);
 
-	int err = SSL_connect( ssl );
-	if( err <= 0 ) {
-		sprintf(message, _("SSL error: %s\n"), ERR_reason_error_string(ERR_get_error()));
+	int err = SSL_connect(ssl);
+	if (err <= 0) {
+		sprintf(message, _("SSL error: %s\n"),
+			ERR_reason_error_string(ERR_get_error()));
 		return NULL;
 	}
 
 	return ssl;
 }
 
-void ssl_disconnect( SSL *ssl )
+void
+ssl_disconnect(SSL *ssl)
 {
-	SSL_shutdown( ssl );
-	SSL_free( ssl );
+	SSL_shutdown(ssl);
+	SSL_free(ssl);
 }
 
-#endif /* HAVE_OPENSSL */
+#endif				/* HAVE_SSL */
