@@ -2,6 +2,8 @@
   Axel -- A lighter download accelerator for Linux and other Unices
 
   Copyright 2016-2017 Stephen Thirlwall
+  Copyright 2017      Antonio Quartulli
+  Copyright 2017      Ismael Luceno
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
@@ -34,10 +36,13 @@
 
 /* SSL interface */
 
-#ifdef HAVE_OPENSSL
+#if !defined(AXEL_SSL_H) && defined(HAVE_SSL)
+#define AXEL_SSL_H
 
-void ssl_init( conf_t *conf );
-SSL* ssl_connect( int fd, char *hostname, char *message );
-void ssl_disconnect( SSL *ssl );
+#include <openssl/ssl.h>
 
-#endif /* HAVE_OPENSSL */
+void ssl_init(conf_t *conf);
+SSL *ssl_connect(int fd, char *hostname, char *message);
+void ssl_disconnect(SSL *ssl);
+
+#endif				/* AXEL_SSL_H */
